@@ -821,7 +821,7 @@ do_open_response (ConnectionData *cd,
 
 	default:
 		if (cddb_debugging == TRUE) {
-			g_print ("CDDB: Unknown response code: %d\n");
+			g_print ("CDDB: Unknown response code: %d\n",code);
 			g_print ("CDDB: %s\n", response);
 		}
 		cddb->priv->access = CDDB_ACCESS_NONE;
@@ -970,7 +970,7 @@ cddb_send_cmd (ConnectionData *data)
 					      data->cddb->priv->port,
 					      open_cb, data);
 	if (sock == NULL) {
-		g_warning ("Could not connect to %s:%s",
+		g_warning ("Could not connect to %s:%d",
 			   data->cddb->priv->server,
 			   data->cddb->priv->port);
 		/* Notify listeners */
@@ -1453,7 +1453,7 @@ impl_GNOME_Media_CDDBSlave2_setYear (PortableServer_Servant servant,
 
 	dyear = g_hash_table_lookup (entry->fields, "DYEAR");
 	if (dyear == NULL) {
-		dyear = g_string_new ("");
+		dyear = g_string_new (NULL);
 		g_string_printf (dyear, "%d", year);
 		g_hash_table_insert (entry->fields, g_strdup ("DYEAR"), dyear);
 	} else {
